@@ -7,6 +7,7 @@ import uuid
 
 import ascend.protos.api.api_pb2 as api_pb2
 from ascend.sdk.client import Client
+from ascend.sdk.common import components_ordered_by_dependency, dataflows_ordered_by_dependency
 from ascend.sdk.definitions import (Component, Connection, Credential, Dataflow, ReadConnector, Transform, WriteConnector, ComponentGroup, ComponentIdToUuidMap,
                                     ComponentUuidType, DataFeed, DataFeedConnector, DataService)
 from openapi_client.exceptions import ApiException
@@ -35,7 +36,7 @@ class DataServiceApplier:
     - dry_run (optional): If set to `True` (`False` by default) - skips any create or
     update operations
     """
-    glog.info(f"Apply DataService: {data_service.id}")
+    glog.info(f"Apply DataService{' (dry_run)' if dry_run else ''}: {data_service.id}")
     exists = False
     try:
       self.client.get_data_service(data_service.id)
@@ -65,9 +66,14 @@ class DataServiceApplier:
     if after_connections:
       after_connections()
 
-    for df in data_service.dataflows:
-      DataflowApplier(self.client).apply(data_service.id, df, delete, dry_run)
-
+    # Handle dataflows carefully, as we want to first create/apply everything, and only after
+    # sweep through and clean up (in reverse order)
+    dataflows = dataflows_ordered_by_dependency(data_service.id, data_service.dataflows)
+    for df in dataflows:
+      DataflowApplier(self.client).apply(data_service.id, df, False, dry_run)
+    if delete:
+      for df in reversed(dataflows):
+        DataflowApplier(self.client)._sweep(data_service.id, df, dry_run)
     try:
       if delete:
         self._sweep(data_service, dry_run)
@@ -79,6 +85,8 @@ class DataServiceApplier:
   def _sweep(self, data_service: DataService, dry_run=False):
     """ Delete any dataflows, credential, or connections that are not part of 'data_service'
     """
+    glog.info(f"Sweeping DataService: {data_service.id}")
+
     expected = [dataflow.id for dataflow in data_service.dataflows]
     # TODO - does not yet account for dependencies between dataflows
     for df in self.client.list_dataflows(data_service.id).data:
@@ -211,17 +219,7 @@ class DataflowApplier:
       resource = DataFeedConnectorApplier(self.client).apply(data_service_id, dataflow.id, dfc, dry_run)
       id_map[dfc.id] = ComponentUuidType(type=dfc.legacy_type(), uuid=resource.uuid)
 
-    id_to_component = _component_id_map_from_list(dataflow.components)
-    g = nx.DiGraph()
-    for component in dataflow.components:
-      g.add_node(component.id)
-      for dep in component.dependencies():
-        # Only include components in this graph - data feed connectors applied separately.
-        if dep in id_to_component:
-          g.add_edge(component.id, dep)
-
-    for component_id in reversed(list(nx.topological_sort(g))):
-      component = id_to_component[component_id]
+    for component in components_ordered_by_dependency(dataflow.components):
       applier = ComponentApplier(self.client, id_map, dry_run)
       resource = applier.apply(data_service_id, dataflow.id, component)
       id_map[component.id] = ComponentUuidType(type=component.legacy_type(), uuid=resource.uuid)
@@ -245,7 +243,7 @@ class DataflowApplier:
   def _apply_dataflow(self, data_service_id: str, dataflow: Dataflow, dry_run=False):
     """ Create a dataflow if it does not already exist, otherwise update it.
     """
-    glog.info(f"Apply Dataflow: (ds={data_service_id} df={dataflow.id})")
+    glog.info(f"Apply Dataflow{' (dry_run)' if dry_run else ''}: (ds={data_service_id} df={dataflow.id})")
     exists = False
     try:
       self.client.get_dataflow(data_service_id, dataflow.id)
@@ -267,6 +265,8 @@ class DataflowApplier:
     """ Delete any components, data feeds, data feed connectors, or component groups
     that are not part of `dataflow`
     """
+    glog.info(f"Sweeping Dataflow: (ds={data_service_id} df={dataflow.id})")
+
     expected_groups = [group.id for group in dataflow.groups]
     for group in self.client.list_component_groups(data_service_id, dataflow.id).data:
       if group.id not in expected_groups:
@@ -546,18 +546,6 @@ class ComponentApplier:
     return ComponentApplier(client, id_map)
 
 
-def _component_id_map_from_list(components: List[Component]) -> Dict[str, Component]:
-  id_to_component: Dict[str, Component] = {}
-  for component in components:
-    if not component.id:
-      raise ValueError("empty component id")
-    elif component.id in id_to_component:
-      raise ValueError(f"duplicate component id {component.id} in component list")
-    else:
-      id_to_component[component.id] = component
-  return id_to_component
-
-
 def _component_id_to_uuid_map(client: Client, data_service_id: str, dataflow_id: str) -> ComponentIdToUuidMap:
   id_map: ComponentIdToUuidMap = {}
   components = client.list_dataflow_components(data_service_id, dataflow_id).data
