@@ -48,6 +48,7 @@ from openapi_client.exceptions import ApiValueError  # noqa: F401,E402
 from openapi_client.exceptions import OpenApiException  # noqa: F401,E402
 
 _HOSTNAME_SUFFIX = ".ascend.io"
+DEFAULT_PROFILE = "default"
 
 # Monkey-patch to always use proto deserialization of JSON for api protos.
 
@@ -115,6 +116,8 @@ class Client:
     ascend_access_key_id=<your_key_id_here>
     ascend_secret_access_key=<your_secret_key_here>`
 
+    If `ASCEND_CREDENTIALS_FILE` is specified, the client looks for credentials at that path instead.
+
     Parameters:
     - hostname: Ascend hostname
     - access_key (optional): Access key
@@ -125,8 +128,6 @@ class Client:
     """
     if not hostname:
       raise ValueError("Must specify hostname")
-    elif not hostname.endswith(_HOSTNAME_SUFFIX):
-      raise ValueError(f"Invalid hostname {hostname}: " f"must follow format <SOMETHING>{_HOSTNAME_SUFFIX}")
     self.hostname = hostname
 
     if not access_key or not secret_key:
@@ -182,7 +183,7 @@ def _get_credentials(hostname: str, verify_ssl=True):
   if hostname.endswith(_HOSTNAME_SUFFIX):
     profile = hostname[:-len(_HOSTNAME_SUFFIX)]
   else:
-    raise ValueError(f"Invalid hostname {hostname}: " f"must follow format <SOMETHING>{_HOSTNAME_SUFFIX}")
+    profile = DEFAULT_PROFILE
 
   config = configparser.ConfigParser()
 
@@ -190,7 +191,11 @@ def _get_credentials(hostname: str, verify_ssl=True):
   secret_key = os.environ.get("ASCEND_SECRET_ACCESS_KEY")
 
   if not access_key and not secret_key:
-    config.read(os.path.expanduser("~/.ascend/credentials"))
+    if os.environ.get("ASCEND_CREDENTIALS_FILE"):
+      credentials_file_path = os.environ.get("ASCEND_CREDENTIALS_FILE")
+    else:
+      credentials_file_path = os.path.expanduser("~/.ascend/credentials")
+    config.read(os.path.expanduser(credentials_file_path))
     try:
       access_key = config.get(profile, "ascend_access_key_id")
       secret_key = config.get(profile, "ascend_secret_access_key")
