@@ -264,20 +264,21 @@ def _inline_code_list_for(component: Component, resource_path_prefix: str, base_
     icl = []
     if component.container:
       details = component.container.record_connection.details
-      write_strategy_value = value_from_proto(details.get('write_strategy', UnionValue()))
-      custom_function = write_strategy_value.get('custom_function')
-      if custom_function:
-        custom_code = custom_function.get('code_interface', {}).get('write_all', {}).get("code_fingerprint_strategy",
-                                                                                         UnionValue()).get("content_based_fingerprint", {}).get("code")
-        if custom_code:
-          icl.append(
-              InlineCode(
-                  code=custom_code,
-                  resource_path=os.path.join(resource_path_prefix, f"{component.id}_custom_code.py"),  # noqa: E126
-                  base_path=base_path,
-                  attribute_path=('container', 'record_connection', 'details', 'write_strategy', 'custom_function', 'code_interface', 'write_all',
-                                  'code_fingerprint_strategy', 'content_based_fingerprint', 'code'),
-                  base64_encoded=False))
+      if details.get('write_strategy'):
+        write_strategy_value = value_from_proto(details.get('write_strategy'))
+        custom_function = write_strategy_value.get('custom_function')
+        if custom_function:
+          custom_code = custom_function.get('code_interface', {}).get('write_all', {}).get("code_fingerprint_strategy",
+                                                                                           UnionValue()).get("content_based_fingerprint", {}).get("code")
+          if custom_code:
+            icl.append(
+                InlineCode(
+                    code=custom_code,
+                    resource_path=os.path.join(resource_path_prefix, f"{component.id}_custom_code.py"),  # noqa: E126
+                    base_path=base_path,
+                    attribute_path=('container', 'record_connection', 'details', 'write_strategy', 'custom_function', 'code_interface', 'write_all',
+                                    'code_fingerprint_strategy', 'content_based_fingerprint', 'code'),
+                    base64_encoded=False))
     return icl
   # TODO(xiaoxi): refactor to make this shorter by traverse down by following the attribute path after extracting the value_from_proto
   elif isinstance(component, ReadConnector):
